summaryrefslogtreecommitdiffhomepage
path: root/config
diff options
context:
space:
mode:
authorNaoto Hanaue <hanaue.naoto@po.ntts.co.jp>2015-08-05 13:56:53 +0900
committerNaoto Hanaue <hanaue.naoto@po.ntts.co.jp>2015-08-05 15:05:12 +0900
commitca99c628a1a1aa65b3a32d42117d0ed712330b68 (patch)
treeddb6fd236a2a6b5a25654fa0db3566611bab4526 /config
parentb7d8d53c486eff0370e9908e75a97b7d8816725c (diff)
config: change the structure of Neighbor.RouteServer as the Neighbor.RouteReflector
Diffstat (limited to 'config')
-rw-r--r--config/bgp_configs.go19
1 files changed, 17 insertions, 2 deletions
diff --git a/config/bgp_configs.go b/config/bgp_configs.go
index 12af5fcb..24e89482 100644
--- a/config/bgp_configs.go
+++ b/config/bgp_configs.go
@@ -279,13 +279,28 @@ type AsPathOptions struct {
AsPathOptionsState AsPathOptionsState
}
-//struct for container bgp:route-server
-type RouteServer struct {
+//struct for container bgp:state
+type RouteServerState struct {
// original -> bgp:route-server-client
//bgp:route-server-client's original type is boolean
RouteServerClient bool
}
+//struct for container bgp:config
+type RouteServerConfig struct {
+ // original -> bgp:route-server-client
+ //bgp:route-server-client's original type is boolean
+ RouteServerClient bool
+}
+
+//struct for container bgp:route-server
+type RouteServer struct {
+ // original -> bgp:route-server-config
+ RouteServerConfig RouteServerConfig
+ // original -> bgp:route-server-state
+ RouteServerState RouteServerState
+}
+
//struct for container bgp:state
type RouteReflectorState struct {
// original -> bgp:route-reflector-cluster-id